# Generated by Django 2.1.2 on 2019-02-24 11:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_saas_email', '0005_mail_bcc_address'),
    ]

    operations = [
        migrations.AddField(
            model_name='mail',
            name='from_name',
            field=models.CharField(blank=True, help_text='Email sender name', max_length=100, null=True, verbose_name='Sender name'),
        ),
        migrations.AddField(
            model_name='mail',
            name='to_name',
            field=models.CharField(blank=True, help_text='Email recipient name', max_length=100, null=True, verbose_name='Recipient name'),
        ),
    ]
