# Generated by Django 2.1.2 on 2019-03-28 14:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_saas_email', '0006_add_to_and_from_names'),
    ]

    operations = [
        migrations.AddField(
            model_name='mailtemplate',
            name='sender_email',
            field=models.EmailField(blank=True, help_text='Email to use as sender address when the template is used. If not set then default address is used', max_length=254, null=True),
        ),
    ]
